@@ -39,8 +39,8 @@ class Pbox(object):
         elif not isinstance(left, np.ndarray):
             right = np.array(right)
         
-        if len(left) == len(right) and len(left) != steps:
-            print("WARNING: The left and right arrays have the same length which is inconsistent with steps.")
+        # if len(left) == len(right) and len(left) != steps:
+        #     print("WARNING: The left and right arrays have the same length which is inconsistent with steps.")
 
         if len(left) != steps:
             left = interpolate(left, interpolation=interpolation, left=False, steps=steps)
@@ -907,7 +907,17 @@ def mixture(*args, w=[], steps=Pbox.STEPS):
     '''
     IMPROVE READBILITY
     '''
-    x = list(args)
+    x = []
+    for a in args:
+        if a.__class__.__name__ != 'Pbox':
+            try:
+                try:
+                    a = box(a)
+                except:
+                    a = Pbox(a)
+            except:
+                raise TypeError("Unable to convert %s object (%s) to Pbox" %(type(a),a))
+        x.append(a)
 
     k = len(x)
     if w == []:
@@ -991,7 +1001,9 @@ def box(a,b = None, steps = Pbox.STEPS):
         var_right=((i.right-i.left)**2)/4
     )
     
-def mmms(minimum, maximum, mean, stddev, **kwargs):
+def mmms(minimum, maximum, mean, stddev, steps = Pbox.STEPS, **kwargs):
+    if minimum == maximum:
+        return box(minimum, maximum)
     def _left(x): 
         if type(x) in [int,float]:
             return x
@@ -1066,4 +1078,4 @@ def mmms(minimum, maximum, mean, stddev, **kwargs):
         R[i] = min(min(min(x2,x3),x6),one) * ran + minimum
   
     v = s**2
-    return Pbox(np.array(L),np.array(R),mean_left=left(m),mean_right=right(m),var_left=left(v),var_right=right(v))
+    return Pbox(np.array(L),np.array(R),mean_left=left(m),mean_right=right(m),var_left=left(v),var_right=right(v),steps = steps)
